import piipaa.piipaa as pp


def test_pp_what_empty(capsys):
    assert pp.what([]) == 0
    out, err = capsys.readouterr()
    assert not err
    assert 'piipaa' in out


def test_pp_what_add_foo(capsys):
    assert pp.what(['foo']) == 0
    out, err = capsys.readouterr()
    assert not err
    assert 'piipaa' in out and 'foo' in out



import importlib.metadata
import importlib.resources
import json
from typing import List, Union, no_type_check

from piipaa import __version__ as my_version


@no_type_check
def read_what():
    """My resources?"""
    with importlib.resources.path(__package__, 'data.json') as data_path:
        with open(data_path, 'rt', encoding='utf-8') as handle:
            return json.load(handle).get('what', 'Oh no!')


def what(argv: Union[List[str], None] = None) -> int:
    """Tell the what and then something else."""
    that = read_what()
    v = importlib.metadata.version(__package__)
    print(that, v, argv, my_version)
    return 0



import piipaa.cli as cli


def test_cli_main_empty(capsys):
    assert cli.main([]) == 0
    out, err = capsys.readouterr()
    assert not err
    assert 'piipaa' in out


def test_cli_main_add_foo(capsys):
    assert cli.main(['foo']) == 0
    out, err = capsys.readouterr()
    assert not err
    assert 'piipaa' in out and 'foo' in out



from importlib.metadata import PackageNotFoundError, version

VERSION_FALLBACK = '2022.4.1'
try:
    __version__ = version(__name__)
except PackageNotFoundError:
    # package is not installed
    # assign signal or sane value as a default
    __version__ = VERSION_FALLBACK
    pass



import sys
from typing import List, Union

import piipaa.piipaa as pp


def main(argv: Union[List[str], None] = None) -> int:
    """Delegate processing to the functional module."""
    argv = sys.argv[1:] if argv is None else argv
    return pp.what(argv)
